@@ -3,8 +3,19 @@
 # Bootstrap and exit if KOLLA_BOOTSTRAP variable is set. This catches all cases
 # of the KOLLA_BOOTSTRAP variable being set, including empty.
 if [[ "${!KOLLA_BOOTSTRAP[@]}" ]]; then
-    nova-manage db sync
     nova-manage api_db sync
+    nova-manage db sync
+    nova-manage db online_data_migrations
+    exit 0
+fi
+
+if [[ "${!KOLLA_UPGRADE[@]}" ]]; then
+    nova-manage api_db sync
+    nova-manage db sync
+    exit 0
+fi
+
+if [[ "${!KOLLA_OSM[@]}" ]]; then
     nova-manage db online_data_migrations
     exit 0
 fi
